AutocompleteResult class

A single autocomplete suggestion from the GeoPlaces API.

Constructors

AutocompleteResult({required String placeId, required String label, required String placeType})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
Human-readable label (e.g. "Sydney Opera House, Bennelong Point").
final
placeId String
The unique place identifier (used for subsequent geocode calls).
final
placeType String
The type of place (e.g. "PointOfInterest", "Street").
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited