GeocodeResult class
A geocode result containing coordinates and address metadata.
Constructors
- GeocodeResult({required String label, required LatLng position, String? country, String? municipality})
-
const
Properties
- country → String?
-
Country name or code (if available).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
Full address label.
final
- municipality → String?
-
Municipality / city (if available).
final
- position → LatLng
-
Geographic coordinates.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited